@@ -20,4 +20,4 @@ def find_factors(num, sort=True):
     step = 2 if num % 2 else 1
     factors = ([i, num // i] for i in range(1, int(num ** 0.5) + 1, step) if num % i == 0)
     rv = set(reduce(list.__add__, factors))
-    return sorted(rv) if sort else rv
+    return sorted(rv) if sort else list(rv)
